@@ -333,6 +333,7 @@ class ToucanConnector(BaseModel, metaclass=ABCMeta):
         filtered by permissions
         """
         res = self._retrieve_data(data_source)
+        res.columns = res.columns.astype(str)
 
         if permissions is not None:
             permissions_query = PandasConditionTranslator.translate(permissions)
@@ -446,7 +447,7 @@ class ToucanConnector(BaseModel, metaclass=ABCMeta):
         if data_source is not None:
             unique_identifier['datasource'] = self._render_datasource(data_source)
 
-        json_uid = JsonWrapper.dumps(unique_identifier, sort_keys=True)
+        json_uid = JsonWrapper.dumps(unique_identifier, sort_keys=True, default=hash)
         string_uid = str(uuid.uuid3(uuid.NAMESPACE_OID, json_uid))
         return string_uid
 
